# fbonnardot - My python tools to do signal processing


This module contains tools that I develop, adapt or translate to do signal processing with Python.

Tools are organized into subfolders associated to themes (cyclostationarity, display, ...).

You can install these tools with pip :

	pip install fbonnardot

*If you change or adapt a function, change its name (for example add your initial after the name)*

These tools were made for :
* personal work (http://frederic.bonnardot.free.fr),
* my research work at [LASPI](https://laspi.univ-st-etienne.fr),
* and for teaching at [IUT de ROANNE](https://iut-roanne.univ-st-etienne.fr).

Do not consider these tools as perfect or free of error. They can help you but be critical about their results.

[![License: AGPL v3](https://img.shields.io/badge/License-AGPL%20v3-blue.svg)](https://www.gnu.org/licenses/agpl-3.0)
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

This code is given as is without warranty of any kind.
In no event shall the authors or copyright holder be liable for any claim damages or other liability.
